/*
 * libebook-contacts.h
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LIBEBOOK_CONTACTS_H
#define LIBEBOOK_CONTACTS_H

#define __LIBEBOOK_CONTACTS_H_INSIDE__

#include <libedataserver/libedataserver.h>

#include <libebook-contacts/e-book-contacts-enums.h>
#include <libebook-contacts/e-book-contacts-enumtypes.h>
#include <libebook-contacts/e-book-contacts-utils.h>
#include <libebook-contacts/e-book-query.h>
#include <libebook-contacts/e-name-western.h>
#include <libebook-contacts/e-address-western.h>
#include <libebook-contacts/e-contact.h>
#include <libebook-contacts/e-vcard.h>
#include <libebook-contacts/e-source-backend-summary-setup.h>
#include <libebook-contacts/e-phone-number.h>

#undef __LIBEBOOK_CONTACTS_H_INSIDE__

#endif /* LIBEBOOK_CONTACTS_H */

